%define _buildid .21

%global python_sitelib %{sys_python_sitelib}
%global __python %{__sys_python}
%global aws_product_name      cfn-init
%global aws_path              /opt/aws
%global aws_bin_path          %{aws_path}/bin
%global aws_product_name_v    %{aws_product_name}-%{version}-%{release}
%global aws_product_path      %{aws_path}/apitools/%{aws_product_name_v}
%global aws_product_path_link %{aws_path}/apitools/%{aws_product_name}

%global upstream_rev 30
%global package_rev 30

Summary: An EC2 bootstrapper for CloudFormation
Name: aws-cfn-bootstrap
Version: 1.4
Release: %{package_rev}%{?_buildid}%{?dist}
Source0: https://s3.amazonaws.com/cfn-init-staging/%{name}-%{version}-%{upstream_rev}.tar.gz
License: Apache 2.0
Group: Development/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildArch: noarch
BuildRequires: system-python
Requires: %{sys_python_pkg}-daemon
Requires: %{sys_python_pkg}-pystache
Requires: %{sys_python_pkg}-setuptools
Provides: bundled(python-requests) = 2.6.0
Url: http://aws.amazon.com/cloudformation/

%description
Bootstraps EC2 instances by retrieving and processing the Metadata block of a CloudFormation resource.

%prep
%setup -n %{name}-%{version}

%build
%{__python} setup.py build

%install
%{__python} setup.py install --root=$RPM_BUILD_ROOT --record=INSTALLED_FILES --install-scripts=%{aws_product_path}/bin --install-data=%{aws_product_path}


%clean
rm -rf $RPM_BUILD_ROOT

%post
# Upgrade- remove old symlink
if [ "$1" = "2" ]; then
    rm -f %{aws_product_path_link}
    # also remove old init script if it exists
    if [ -e  %{_initrddir}/cfn-hup ]; then
        rm -f  %{_initrddir}/cfn-hup
    fi
fi

# Install/Upgrade - Create symlink from versioned
# directory to product name directory if it doesn't exist
if [ ! -e  %{aws_product_path_link} ]; then
    ln -s  ./%{aws_product_name_v}  %{aws_product_path_link}
fi

# Create aws bin directory if it doesn't exist:
if [ ! -d %{aws_bin_path} ]; then
    mkdir %{aws_bin_path}
fi

for command in %{aws_product_path_link}/bin/*; do
    %define command_name $(basename $command)
    if [ -e %{aws_bin_path}/%{command_name} ]; then
        if [ "$1" = "2" ]; then
            # Upgrade- remove old symlinks
            rm -f %{aws_bin_path}/%{command_name}
        fi
    fi
    if [ ! -h %{aws_bin_path}/%{command_name} ]; then
    # Install relative symlink from generic directory to aws shared directory
        ln -s ../apitools/%{aws_product_name}/bin/%{command_name}  %{aws_bin_path}/%{command_name}
    fi
done

# Create link to init script
if [ ! -e %{_initrddir}/cfn-hup ]; then
    ln -s %{aws_product_path_link}/init/redhat/cfn-hup  %{_initrddir}/cfn-hup
fi

chmod 755 %{_initrddir}/cfn-hup
chmod 755 %{aws_product_path_link}/init/redhat/cfn-hup


%preun
# Uninstall: 
if [ "$1" = "0" ]; then
    #Clean up the symlinks if it points to this version
    if [ "x$(readlink %{aws_product_path_link})" == "x./%{aws_product_name_v}" ]; then
        for command in %{aws_bin_path}/cfn*; do
            if [ "x$(readlink $command)" == "x../apitools/%{aws_product_name}/bin/$(basename $command)" ]; then
                rm -f $command
            fi
        done
    fi
fi

%postun
if [ "$1" = "0" ]; then
    if [ ! "$(ls -A %{aws_bin_path})" ]; then
        rmdir %{aws_bin_path}
    fi

    rm -f %{aws_product_path_link}

    if [ ! "$(ls -A %{aws_path}/apitools)" ]; then
        rmdir %{aws_path}/apitools
    fi

    if [ ! "$(ls -A %{aws_path})" ]; then
        rmdir %{aws_path}
    fi
fi

%files -f INSTALLED_FILES

%changelog
* Wed Apr 18 2018 Heath Petty <hpetty@amazon.com>
- Update to 1.4-30

* Tue Feb 20 2018 Heath Petty <hpetty@amazon.com>
- Update to 1.4-29

* Wed Dec 20 2017 Heath Petty <hpetty@amazon.com>
- Update to 1.4-27

* Fri Nov 3 2017 Heath Petty <hpetty@amazon.com>
- update to 1.4-26

* Wed Oct 11 2017 Heath Petty <hpetty@amazon.com>
- update to 1.4-24

* Tue Sep 26 2017 Iliana Weller <iweller@amazon.com>
- Update to 1.4-23

* Thu Sep 14 2017 Heath Petty <hpetty@amazon.com>
- Update to 1.4-22

* Wed Aug 30 2017 Heath Petty <hpetty@amazon.com>
- Update to 1.4-21

* Wed Aug 2 2017 Iliana Weller <iweller@amazon.com>
- Update to 1.4-20

* Wed Jul 19 2017 C.J. Harris <harric@amazon.com>
- Update aws-cfn-bootstrap to a new unpackaged version (with a cfn-hup security fix)

* Wed Dec 14 2016 Heath Petty <hpetty@amazon.com>
- Update to 1.4-15 for ca-central-1 and eu-west-2 support

* Tue Oct 11 2016 Ian Weller <iweller@amazon.com>
- Update to 1.4-13 for us-east-2 support

* Wed Sep 7 2016 Ian Weller <iweller@amazon.com>
- Update to 1.4-12 for ap-south-1 support

* Mon May 16 2016 Ian Weller <iweller@amazon.com>
- Resync to latest 1.4-11

* Tue Sep 22 2015 Sean Kelly <seankell@amazon.com>
- Resync to latest 1.4-10

* Fri May 15 2015 Sean Kelly <seankell@amazon.com>
- Add Requires on setuptools

* Thu Apr 16 2015 Sean Kelly <seankell@amazon.com>
- Move to version 1.4-8

* Wed Mar 25 2015 Jamie Anderson <jamieand@amazon.com>
- Update the bundled Requests to 2.6.0

* Fri Feb 6 2015 Jamie Anderson <jamieand@amazon.com>
- Build for Python 2.7
- setup complete for package aws-cfn-bootstrap
